@@ -66,7 +66,7 @@ impl Contract {
         byte_price: Word,
         maturity: Word,
         custom_inputs: bool,
-    ) -> Result<Vec<Receipt>, String> {
+    ) -> Result<Vec<Receipt>, Error> {
         // Based on the defined script length,
         // we set the appropriate data offset.
         let script_len = 16;
@@ -169,7 +169,7 @@ impl Contract {
 
         let script = Script::new(tx);
 
-        Ok(script.call(fuel_client).await.unwrap())
+        script.call(fuel_client).await
     }
 
     /// Creates an ABI call based on a function selector and
@@ -348,17 +348,40 @@ where
             self.maturity,
             self.custom_inputs,
         )
-        .await
-        .unwrap();
+        .await?;
 
-        let (encoded_value, index) = match receipts.iter().find(|&receipt| receipt.val().is_some())
-        {
-            Some(r) => {
-                let index = receipts.iter().position(|elt| elt == r).unwrap();
-                (r.val().unwrap().to_be_bytes(), Some(index))
-            }
-            None => ([0u8; 8], None),
+        // If it's an ABI method without a return value, exit early.
+        if self.output_params.is_empty() {
+            return Ok(CallResponse {
+                value: D::from_tokens(vec![])?,
+                receipts,
+            });
+        }
+
+        // Right now we only support methods with a single return type.
+        // Soon we'll support tuple as a return type and we'll have to update the logic in here.
+        let output_param = &self.output_params[0];
+
+        // If the method's return type is bigger than a single `WORD`, the returned value
+        // is stored in `ReturnData.data`, otherwise, it's stored in `Return.val`.
+        // Here we're checking for that.
+        let (encoded_value, index) = match output_param.bigger_than_word() {
+            true => match receipts.iter().find(|&receipt| receipt.data().is_some()) {
+                Some(r) => {
+                    let index = receipts.iter().position(|elt| elt == r).unwrap();
+                    (r.data().unwrap().to_vec(), Some(index))
+                }
+                None => (vec![], None),
+            },
+            false => match receipts.iter().find(|&receipt| receipt.val().is_some()) {
+                Some(r) => {
+                    let index = receipts.iter().position(|elt| elt == r).unwrap();
+                    (r.val().unwrap().to_be_bytes().to_vec(), Some(index))
+                }
+                None => (vec![], None),
+            },
         };
+
         if index.is_some() {
             receipts.remove(index.unwrap());
         }
